dj_oydiv package
================

Subpackages
-----------

.. toctree::

    dj_oydiv.admin
    dj_oydiv.auth
    dj_oydiv.config
    dj_oydiv.middleware
    dj_oydiv.migrations
    dj_oydiv.utils
    dj_oydiv.views

Submodules
----------

dj_oydiv.exceptions module
--------------------------

.. automodule:: dj_oydiv.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.models module
----------------------

.. automodule:: dj_oydiv.models
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.rpc_wrapper module
---------------------------

.. automodule:: dj_oydiv.rpc_wrapper
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.version module
-----------------------

.. automodule:: dj_oydiv.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dj_oydiv
    :members:
    :undoc-members:
    :show-inheritance:
